@@ -8,7 +8,7 @@ try:
 except ImportError:
     from kfp.components import load_component_from_file
 
-__all__ = ["AddPyOp", "MakeCascadeFileOp", "VideoToFramesOp"]
+__all__ = ["AddPyOp", "MakeCascadeFileOp", "VideoToFramesOp", "HaarFromFramesOp"]
 
 AddPyOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "add_py/component.yaml")
@@ -21,3 +21,7 @@ MakeCascadeFileOp = load_component_from_file(
 VideoToFramesOp = load_component_from_file(
     os.path.join(os.path.dirname(__file__), "video_to_frames/component.yaml")
 )
+
+HaarFromFramesOp = load_component_from_file(
+    os.path.join(os.path.dirname(__file__), "haar_from_frames/component.yaml")
+)
