@@ -1,21 +1,21 @@
-from hoodat_vertex_components.components.make_cascade_file.filter_cascades import (
+from make_cascade_file import (
     filter_cascades,
 )
 
 
 def test_filter_cascades_correct_rows():
-    df = filter_cascades(ids=[0, 1])
+    df = filter_cascades(cascade_ids=[0, 1])
     assert df.shape[0] == 2
     assert df["file"][1] == "haarcascade_frontalface_alt.xml"
 
 
 def test_filter_cascades_empty_rows():
-    df = filter_cascades(ids=[])
+    df = filter_cascades(cascade_ids=[])
     assert df.shape[0] == 0
 
 
 def test_filter_cascades_row_order():
-    df = filter_cascades(ids=[1, 0, 2])
+    df = filter_cascades(cascade_ids=[1, 0, 2])
     assert df.shape[0] == 3
     assert df["id"][1] == 1
     assert df["name"][1] == "frontalface_alt"
@@ -23,5 +23,5 @@ def test_filter_cascades_row_order():
 
 
 def test_filter_cascades_all_rows():
-    df = filter_cascades(ids=[0, 1, 2, 3, 4, 5, 6])
+    df = filter_cascades(cascade_ids=[0, 1, 2, 3, 4, 5, 6])
     assert df.shape[0] == 7
